@@ -6,6 +6,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <panel-applet.h>
 
 #include <stdlib.h>
@@ -56,7 +57,6 @@ time_t last_timeout;
 tm *last_tm;
 
 GtkImage *icon;
-GtkTooltips *tooltips;
 GtkWidget *ebox;
 
 GdkPixbuf *static_swirl;
@@ -70,6 +70,10 @@ guint from_slave_input;
 // Stores the timeout for the update.
 guint update_timeout;
 
+// Menu action group
+GtkActionGroup *menu_action_group;
+
+
 static gboolean do_update(gpointer data);
 static gboolean do_update_timeout(gpointer data);
 static gboolean do_reload(gpointer data);
@@ -92,19 +96,16 @@ static void start_log()
 
   if(log==NULL)
     {
-      gchar *message=g_strdup_printf("Couldn't open the debugging log file %s!",
-				     fn);
-
       GtkWidget *dlg=gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_CLOSE,
-					    message);
+                        "Couldn't open the debugging log file %s!",
+					    fn);
 
       gtk_dialog_run(GTK_DIALOG(dlg));
 
       gtk_widget_destroy(dlg);
 
-      g_free(message);
     }
 
   g_free(fn);
@@ -209,23 +210,23 @@ void setup_update_timeout(PanelApplet *applet)
 
   CheckFreq freq=get_check_freq(applet);
 
+  GError *err=NULL;
+
+  string key=string(panel_applet_get_preferences_key(applet))+"/check/last_check";
+
+  last_timeout=gconf_client_get_int(confclient,
+                                    key.c_str(),
+                                    &err);
+  last_tm = localtime(&last_timeout);
+  if(err!=NULL)
+  {
+    last_timeout=0;
+    g_error_free(err);
+    err=NULL;
+  }
+
   if(freq!=CHECK_NEVER)
     {
-      GError *err=NULL;
-
-      string key=string(panel_applet_get_preferences_key(applet))+"/check/last_check";
-
-      last_timeout=gconf_client_get_int(confclient,
-					       key.c_str(),
-					       &err);
-      last_tm = localtime(&last_timeout);
-      if(err!=NULL)
-	{
-	  last_timeout=0;
-	  g_error_free(err);
-	  err=NULL;
-	}
-
       time_t next_timeout=last_timeout+(freq==CHECK_WEEKLY?7:1)*24*60*60;
 
       time_t curtime=time(0);
@@ -267,8 +268,8 @@ static void notify_download_upgrades(GConfClient *client,
   maybe_download((PanelApplet *) userdata);
 }
 
-static void bonobo_about(BonoboUIComponent *component, gpointer data,
-			  const char *name)
+static void bonobo_about(GtkAction       *action,
+                         gpointer data)
 {
   GtkBuilder *builder;
   GError *error=NULL;
@@ -283,22 +284,22 @@ static void bonobo_about(BonoboUIComponent *component, gpointer data,
   gtk_builder_connect_signals(builder, NULL);
 }
 
-static void bonobo_update(BonoboUIComponent *component, gpointer data,
-			  const char *name)
+static void bonobo_update(GtkAction       *action,
+                         gpointer data)
 {
   do_update(data);
 }
 
-static void bonobo_start(BonoboUIComponent *component, gpointer data,
-			 const char *name)
+static void bonobo_start(GtkAction       *action,
+                         gpointer data)
 {
   PanelApplet *applet=(PanelApplet *) data;
 
   start_slave(applet);
 }
 
-static void bonobo_prefs(BonoboUIComponent *component, gpointer data,
-			 const char *name)
+static void bonobo_prefs(GtkAction       *action,
+                         gpointer data)
 {
   do_preferences(data);
 }
@@ -312,15 +313,15 @@ static void start_package_manager(PanelApplet *applet)
   write_string(to_slave, manager->cmd);
 }
 
-static void bonobo_package_manager(BonoboUIComponent *component, gpointer data,
-				   const char *name)
+static void bonobo_package_manager(GtkAction       *action,
+                         gpointer data)
 {
   if(state==IDLE)
     start_package_manager(PANEL_APPLET(data));
 }
 
-static void bonobo_download(BonoboUIComponent *component, gpointer data,
-			    const char *name)
+static void bonobo_download(GtkAction       *action,
+                         gpointer data)
 {
   if(state==IDLE)
     {
@@ -331,56 +332,54 @@ static void bonobo_download(BonoboUIComponent *component, gpointer data,
     }
 }
 
-static void bonobo_cancel_download(BonoboUIComponent *component, gpointer data,
-				   const char *name)
+static void bonobo_cancel_download(GtkAction       *action,
+                         gpointer data)
 {
   if(state==DOWNLOADING || state==UPDATING)
     write_msgid(to_slave, APPLET_CMD_ABORT_DOWNLOAD);
 }
 
-static const BonoboUIVerb my_verbs[]={
-  BONOBO_UI_VERB("UpdateNow", bonobo_update),
-  BONOBO_UI_VERB("Start", bonobo_start),
-  BONOBO_UI_VERB("Preferences", bonobo_prefs),
-  BONOBO_UI_VERB("About", bonobo_about),
-  BONOBO_UI_VERB("PkgManager", bonobo_package_manager),
-  BONOBO_UI_VERB("Download", bonobo_download),
-  BONOBO_UI_VERB("CancelDownload", bonobo_cancel_download),
-  BONOBO_UI_VERB_END
+static const GtkActionEntry my_verbs[]={
+    { "Start", NULL, N_("Start"), NULL, NULL, G_CALLBACK (bonobo_start)},
+    { "UpdateNow", NULL, N_("Update Now"), NULL, NULL, G_CALLBACK (bonobo_update)},
+    { "PkgManager", NULL, N_("Open Package Manager"), NULL, NULL, G_CALLBACK (bonobo_package_manager)},
+    { "Download", NULL, N_("Download"), NULL, NULL, G_CALLBACK (bonobo_download)},
+    { "CancelDownload", NULL, N_("Cancel Download"), NULL, NULL, G_CALLBACK (bonobo_cancel_download)},
+    { "Preferences", NULL, N_("Preferences"), NULL, NULL, G_CALLBACK (bonobo_prefs)},
+    { "About", GTK_STOCK_ABOUT, N_("About"), NULL, NULL, G_CALLBACK (bonobo_about) }
 };
 
 const char my_menu[]=
-"<popup name=\"button3\">"
-  "<menuitem name=\"Start\" verb=\"Start\" _label=\"_Start watching for upgrades\"/>"
-  "<menuitem name=\"UpdateNow\" verb=\"UpdateNow\" _label=\"Check for _upgrades\" pixname=\"gtk-search\"/>"
-  "<menuitem name=\"PkgManager\" verb=\"PkgManager\" _label=\"Run package manager\" pixname=\"gtk-go-right\"/>"
-  "<menuitem name=\"Download\" verb=\"Download\" _label=\"Download all upgrades\" pixname=\"gtk-go-down\"/>"
-  "<menuitem name=\"CancelDownload\" verb=\"CancelDownload\" _label=\"Cancel download\" pixname=\"gtk-stop\"/>"
-  "<menuitem name=\"Preferences\" verb=\"Preferences\" _label=\"_Preferences...\" pixtype=\"stock\" pixname=\"gtk-preferences\"/>"
-  "<menuitem name=\"About\" verb=\"About\" _label=\"_About...\" pixtype=\"stock\" pixname=\"gnome-stock-about\"/>"
-  "</popup>";
+    "<menuitem name=\"Start\" action=\"Start\" />"
+    "<menuitem name=\"Update Now\" action=\"UpdateNow\" />"
+    "<menuitem name=\"Open Package Manager\" action=\"PkgManager\" />"
+    "<menuitem name=\"Download\" action=\"Download\" />"
+    "<menuitem name=\"Cancel Download\" action=\"CancelDownload\" />"
+    "<menuitem name=\"Preferences\" action=\"Preferences\" />"
+    "<menuitem name=\"About\" action=\"About\" />";
 
-// Wrapper around the nastiness that is the Gnome API
-//
-// (actually I'm just bitter that a really simple operation took me 5
-// hours to figure out)
 static void set_menu_sensitive(PanelApplet *applet,
 			       const string &item, bool sensitive)
 {
-  BonoboUIComponent *popup = panel_applet_get_popup_component(applet);
-
-  bonobo_ui_component_set_prop(popup, ("/commands/"+item).c_str(), "sensitive",
-			       sensitive?"1":"0", NULL);
+    GtkAction *selected_action = gtk_action_group_get_action(menu_action_group, item.c_str());
+    if (selected_action != NULL) {
+        gtk_action_set_sensitive(selected_action, sensitive);
+    }
+    else {
+        do_log("Failed to find GtkAction %s for set_menu_sensitive()", item.c_str());
+    }
 }
 
-// Similarly
-static void set_menu_hidden(PanelApplet *applet,
-			    const string &item, bool hidden)
+static void set_menu_visible(PanelApplet *applet,
+			    const string &item, bool visible)
 {
-  BonoboUIComponent *popup = panel_applet_get_popup_component(applet);
-
-  bonobo_ui_component_set_prop(popup, ("/commands/"+item).c_str(), "hidden",
-			       hidden?"1":"0", NULL);
+    GtkAction *selected_action = gtk_action_group_get_action(menu_action_group, item.c_str());
+    if (selected_action != NULL) {
+        gtk_action_set_visible(selected_action, visible);
+    }
+    else {
+        do_log("Failed to find GtkAction %s for set_menu_visible()", item.c_str());
+    }
 }
 
 static void set_state(applet_state new_state,
@@ -465,7 +464,7 @@ static void set_state(applet_state new_state,
       msg=buf;
     }
 
-  gtk_tooltips_set_tip(tooltips, ebox, msg.c_str(), "");
+  gtk_widget_set_tooltip_text (ebox, msg.c_str());
 
   if((state==IDLE) &&
      pending_update)
@@ -481,8 +480,8 @@ static void set_state(applet_state new_state,
       do_reload(applet);
     }
 
-  set_menu_hidden(applet, "Start", state!=NEED_SLAVE_START);
-  set_menu_hidden(applet, "CancelDownload", !(state==DOWNLOADING || state==UPDATING));
+  set_menu_visible(applet, "Start", state==NEED_SLAVE_START);
+  set_menu_visible(applet, "CancelDownload", (state==DOWNLOADING || state==UPDATING));
 
   set_menu_sensitive(applet, "UpdateNow", state==IDLE);
   set_menu_sensitive(applet, "Download", state==IDLE);
@@ -568,8 +567,6 @@ report_failed_grab (const char *what)
 			       "A malicious client may be eavesdropping "
 			       "on your session.", what);
   gtk_window_set_position(GTK_WINDOW(err), GTK_WIN_POS_CENTER);
-  gtk_label_set_line_wrap(GTK_LABEL((GTK_MESSAGE_DIALOG(err))->label),
-			  TRUE);
 
   gtk_dialog_run(GTK_DIALOG(err));
 
@@ -599,7 +596,7 @@ static int ask_for_auth_info(const string &msg, bool echo)
 				  msg.c_str());
 
   entry = gtk_entry_new();
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), entry, FALSE, 
+  gtk_box_pack_start(GTK_BOX(gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG(dialog))), entry, FALSE,
 		     FALSE, 0);
   if(!echo)
     gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
@@ -608,8 +605,6 @@ static int ask_for_auth_info(const string &msg, bool echo)
 
   gtk_window_set_title(GTK_WINDOW(dialog), "Upgrade notification");
   gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
-  gtk_label_set_line_wrap(GTK_LABEL((GTK_MESSAGE_DIALOG(dialog))->label),
-			  TRUE);
 
   /* Make <enter> close dialog */
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
@@ -618,8 +613,10 @@ static int ask_for_auth_info(const string &msg, bool echo)
 
   /* Grab focus */
   gtk_widget_show_now(dialog);
-  status = gdk_keyboard_grab((GTK_WIDGET(dialog))->window, FALSE,
+
+  status = gdk_keyboard_grab(gtk_widget_get_parent_window(dialog), FALSE,
 			     GDK_CURRENT_TIME);
+
   if (status != GDK_GRAB_SUCCESS)
     {
       failed = "keyboard";
@@ -966,8 +963,6 @@ static gboolean handle_slave_msg(GIOChannel *source,
 				     s.c_str());
 
 	  gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
-	  gtk_label_set_line_wrap(GTK_LABEL((GTK_MESSAGE_DIALOG(dlg))->label),
-				  TRUE);
 
 	  gtk_dialog_run(GTK_DIALOG(dlg));
 
@@ -1004,8 +999,6 @@ static gboolean handle_slave_msg(GIOChannel *source,
 				     msgtype);
 
 	  gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
-	  gtk_label_set_line_wrap(GTK_LABEL((GTK_MESSAGE_DIALOG(dlg))->label),
-				  TRUE);
 
 	  gtk_dialog_run(GTK_DIALOG(dlg));
 
@@ -1043,11 +1036,10 @@ static void run_error_dlg(const char *message)
   GtkWidget *dlg=gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_CLOSE,
-					message);
+                    "%s",
+                    message);
 
   gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
-  gtk_label_set_line_wrap(GTK_LABEL((GTK_MESSAGE_DIALOG(dlg))->label),
-			  TRUE);
 
   gtk_dialog_run(GTK_DIALOG(dlg));
 
@@ -1186,17 +1178,17 @@ apt_watch_applet_fill (PanelApplet *applet,
 
   signal(SIGPIPE, SIG_IGN);
 
-  if (strcmp (iid, "OAFIID:Apt_WatchApplet") != 0)
+  if (strcmp (iid, "Apt_WatchApplet") != 0)
     return FALSE;
 
-  panel_applet_setup_menu(applet, my_menu, my_verbs, applet);
+  menu_action_group = gtk_action_group_new("Apt-Watch Applet Actions");
+  gtk_action_group_add_actions(menu_action_group, my_verbs, G_N_ELEMENTS(my_verbs), applet);
+  panel_applet_setup_menu(applet, my_menu, menu_action_group);
 
   ebox=gtk_event_box_new();
   g_signal_connect(G_OBJECT(ebox), "button-press-event",
 		   (GCallback) applet_button_pressed, applet);
 
-  tooltips=gtk_tooltips_new();
-
   GError *err=NULL;
   static_swirl=gdk_pixbuf_new_from_file(DATADIR "/apt-watch/pixmaps/gnome-debian-small.png", &err);
   handle_gerror("Unable to load the swirl pixmap from " DATADIR "/apt-watch/pixmaps/gnome-debian-small.png: %s", &err);
@@ -1245,10 +1237,7 @@ apt_watch_applet_fill (PanelApplet *applet,
   return TRUE;
 }
 
-
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:Apt_WatchApplet_Factory",
-                             PANEL_TYPE_APPLET,
-                             "Watch for upgrades",
-                             "0",
-                             apt_watch_applet_fill,
-                             NULL);
+PANEL_APPLET_OUT_PROCESS_FACTORY ( "Apt_WatchApplet_Factory",
+                                   PANEL_TYPE_APPLET,
+                                   apt_watch_applet_fill,
+                                   NULL);
