@@ -1,6 +1,7 @@
 // prefs-download-upgrade.h                        -*-c++-*-
 //
 //  Copyright 2004 Daniel Burrows
+//  Copyright 2011 John Lightsey
 //
 // Code to manage the "what upgrades to download" portion of the preferences
 // dialog.
@@ -10,10 +11,10 @@
 
 struct _PanelApplet;
 typedef struct _PanelApplet PanelApplet;
-struct _GladeXML;
-typedef struct _GladeXML GladeXML;
+struct _GtkBuilder;
+typedef struct _GtkBuilder GtkBuilder;
 
-void init_preferences_download_upgrades(PanelApplet *applet, GladeXML *xml);
+void init_preferences_download_upgrades(PanelApplet *applet, GtkBuilder *builder);
 
 
 #endif  // PREFS_DOWNLOAD_UPGRADE_H
