@@ -1,6 +1,7 @@
 // prefs-notify.h                        -*-c++-*-
 //
 //  Copyright 2004 Daniel Burrows
+//  Copyright 2011 John Lightsey
 //
 // Code to manage the "notifications about upgrades" dialog.
 
@@ -9,10 +10,10 @@
 
 struct _PanelApplet;
 typedef struct _PanelApplet PanelApplet;
-struct _GladeXML;
-typedef struct _GladeXML GladeXML;
+struct _GtkBuilder;
+typedef struct _GtkBuilder GtkBuilder;
 
-void init_preferences_notify(PanelApplet *applet, GladeXML *xml);
+void init_preferences_notify(PanelApplet *applet, GtkBuilder *builder);
 
 
 #endif  // PREFS_NOTIFY_H
